summaryrefslogtreecommitdiff
path: root/src/include/donaudb_plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/donaudb_plugin.h')
-rw-r--r--src/include/donaudb_plugin.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/donaudb_plugin.h b/src/include/donaudb_plugin.h
index cda587d..e885399 100644
--- a/src/include/donaudb_plugin.h
+++ b/src/include/donaudb_plugin.h
@@ -519,7 +519,7 @@ struct DONAUDB_Plugin
* Insert submitted donation receipt from the donor.
*
* @param cls closure
* @param h_tax_number salted hash of the donors tax number
* @param nonce nonce that is part of the unique donation identifier
* @param donation_unit_pub donation unit public key
* @param donau_sig donau signature in case the sign keys changed
@@ -529,7 +529,7 @@ struct DONAUDB_Plugin
enum GNUNET_DB_QueryStatus
(*insert_submitted_receipts)(
void *cls,
- struct DONAU_HashDonorTaxId *h_tax_number,
+ struct DONAU_HashDonorTaxId *h_donor_tax_id,
size_t num_dr,
const struct DONAU_DonationReceipt donation_receipts[static num_dr],
uint64_t donation_year);
@@ -519,7 +519,7 @@ struct DONAUDB_Plugin
*
* @param cls closure
- * @param h_tax_number salted hash of the donors tax number
+ * @param h_donor_tax_id salted hash of the donors tax number
* @param nonce nonce that is part of the unique donation identifier
* @param donation_unit_pub donation unit public key